@@ -67,6 +67,7 @@ my %port_for = (
    chan_master1 => 2900,
    chan_master2 => 2901,
    chan_slave1  => 2902,
+   chan_slave2  => 2903,
 );
 
 my %server_type = (
@@ -133,7 +134,7 @@ sub create_dbs {
 sub get_dbh_for {
    my ( $self, $server, $cxn_ops, $user ) = @_;
    _check_server($server);
-   $cxn_ops ||= { AutoCommit => 1 };
+   $cxn_ops ||= { AutoCommit => 1, mysql_enable_utf8 => 1 };
    $user    ||= 'msandbox';
    PTDEBUG && _d('dbh for', $server, 'on port', $port_for{$server});
    my $dp = $self->{DSNParser};
@@ -211,6 +212,7 @@ sub wipe_clean {
 
    $self->wait_for_slaves();
 
+   $self->clear_genlogs();
    return;
 }
 
@@ -365,6 +367,10 @@ sub verify_test_data {
    $self->{checksum_ref} = $ref unless $self->{checksum_ref};
    my @tables_in_mysql  = grep { !/^(?:innodb|slave)_/ }
                           grep { !/_log$/ }
+                          grep { !/engine_cost$/ }
+                          grep { !/server_cost$/ }
+                          grep { !/tables_priv$/ }
+                          grep { !/user$/ }
                           @{$master->selectcol_arrayref('SHOW TABLES FROM mysql')};
    my @tables_in_sakila = qw(actor address category city country customer
                              film film_actor film_category film_text inventory
@@ -387,7 +393,7 @@ sub verify_test_data {
    my @diffs;
    foreach my $c ( @checksums ) {
       next unless $c->{checksum};
-      if ( $c->{checksum} ne $ref->{$c->{table}}->{checksum} ) {
+      if ( $ref->{$c->{table}} && $c->{checksum} ne $ref->{$c->{table}}->{checksum} ) {
          push @diffs, $c->{table};
       }
    }
