@@ -7,6 +7,8 @@ import (
 	"os/exec"
 	"regexp"
 	"strings"
+
+	"go.mongodb.org/mongo-driver/bson"
 )
 
 const (
@@ -45,7 +47,7 @@ func LoadJson(filename string, destination interface{}) error {
 	return nil
 }
 
-func LoadBson(filename string, destination interface{}) error {
+func LoadBsonold(filename string, destination interface{}) error {
 	file, err := os.Open(filename)
 	if err != nil {
 		return err
@@ -85,6 +87,26 @@ func LoadBson(filename string, destination interface{}) error {
 	return nil
 }
 
+func LoadBson(filename string, destination interface{}) error {
+	file, err := os.Open(filename)
+	if err != nil {
+		return err
+	}
+	defer file.Close()
+
+	buf, err := ioutil.ReadAll(file)
+	if err != nil {
+		return err
+	}
+
+	err = bson.UnmarshalExtJSON(buf, true, destination)
+	if err != nil {
+		return err
+	}
+
+	return nil
+}
+
 func WriteJson(filename string, data interface{}) error {
 
 	buf, err := json.MarshalIndent(data, "", "  ")
