@@ -1,24 +1,21 @@
 package fingerprinter
 
 import (
-	"encoding/json"
 	"fmt"
 	"regexp"
 	"sort"
 	"strings"
 
+	"github.com/percona/percona-toolkit/src/go/mongolib/proto"
 	"go.mongodb.org/mongo-driver/bson"
 	"go.mongodb.org/mongo-driver/bson/primitive"
-
-	"github.com/percona/percona-toolkit/src/go/mongolib/proto"
-	"github.com/percona/percona-toolkit/src/go/mongolib/util"
 )
 
-var (
-	MAX_DEPTH_LEVEL     = 10
-	DEFAULT_KEY_FILTERS = []string{"^shardVersion$"}
+const (
+	maxDepthLevel = 10
 )
 
+// Fingerprint models the MongnDB query fingeprint result fields.
 type Fingerprint struct {
 	Namespace   string
 	Operation   string
@@ -28,24 +25,28 @@ type Fingerprint struct {
 	Fingerprint string
 }
 
+// Fingerprinter holds unexported fields and public methods for fingerprinting queries.
 type Fingerprinter struct {
 	keyFilters []string
 }
 
+// DefaultKeyFilters returns the default keys used to filter out some keys
+// from the fingerprinter.
+func DefaultKeyFilters() []string {
+	return []string{"^shardVersion$"}
+}
+
+// NewFingerprinter returns a new Fingerprinter object
 func NewFingerprinter(keyFilters []string) *Fingerprinter {
 	return &Fingerprinter{
 		keyFilters: keyFilters,
 	}
 }
 
+// Fingerprint process a query input to build it's fingerprint.
 func (f *Fingerprinter) Fingerprint(doc proto.SystemProfile) (Fingerprint, error) {
-	realQuery, err := util.GetQueryField(doc)
+	realQuery, err := GetQueryFieldD(doc)
 	if err != nil {
-		// Try to encode doc.Query as json for prettiness
-		if buf, err := json.Marshal(realQuery); err == nil {
-			return Fingerprint{}, fmt.Errorf("%v for query %s", err, string(buf))
-		}
-		// If we cannot encode as json, return just the error message without the query
 		return Fingerprint{}, err
 	}
 	retKeys := keys(realQuery, f.keyFilters)
@@ -55,26 +56,22 @@ func (f *Fingerprinter) Fingerprint(doc proto.SystemProfile) (Fingerprint, error
 	// however MongoDB 3.0 doesn't have that field
 	// so we need to detect protocol by looking at actual data.
 	query := doc.Query
-	if doc.Command.Len() > 0 {
+	if len(doc.Command) > 0 {
 		query = doc.Command
 	}
 
 	// if there is a sort clause in the query, we have to add all fields in the sort
 	// fields list that are not in the query keys list (retKeys)
 	if sortKeys, ok := query.Map()["sort"]; ok {
-		if sortKeysMap, ok := sortKeys.(bson.M); ok {
-			sortKeys := keys(sortKeysMap, f.keyFilters)
-			retKeys = append(retKeys, sortKeys...)
-		}
+		sortKeys := keys(sortKeys, f.keyFilters)
+		retKeys = append(retKeys, sortKeys...)
 	}
 
 	// if there is a orderby clause in the query, we have to add all fields in the sort
 	// fields list that are not in the query keys list (retKeys)
 	if sortKeys, ok := query.Map()["orderby"]; ok {
-		if sortKeysMap, ok := sortKeys.(bson.M); ok {
-			sortKeys := keys(sortKeysMap, f.keyFilters)
-			retKeys = append(retKeys, sortKeys...)
-		}
+		sortKeys := keys(sortKeys, f.keyFilters)
+		retKeys = append(retKeys, sortKeys...)
 	}
 
 	// Extract operation, collection, database and namespace
@@ -88,6 +85,7 @@ func (f *Fingerprinter) Fingerprint(doc proto.SystemProfile) (Fingerprint, error
 	if len(ns) == 2 {
 		collection = ns[1]
 	}
+
 	switch doc.Op {
 	case "remove", "update":
 		op = doc.Op
@@ -110,7 +108,7 @@ func (f *Fingerprinter) Fingerprint(doc proto.SystemProfile) (Fingerprint, error
 		}
 		op = "find"
 	case "command":
-		if query.Len() == 0 {
+		if len(query) == 0 {
 			break
 		}
 		// first key is operation type
@@ -120,21 +118,20 @@ func (f *Fingerprinter) Fingerprint(doc proto.SystemProfile) (Fingerprint, error
 		case "group":
 			retKeys = []string{}
 			if g, ok := query.Map()["group"]; ok {
-				if m, ok := g.(bson.M); ok {
-					if f, ok := m["key"]; ok {
-						if keysMap, ok := f.(bson.M); ok {
-							retKeys = append(retKeys, keys(keysMap, []string{})...)
-						}
-					}
-					if f, ok := m["cond"]; ok {
-						if keysMap, ok := f.(bson.M); ok {
-							retKeys = append(retKeys, keys(keysMap, []string{})...)
-						}
-					}
-					if f, ok := m["ns"]; ok {
-						if ns, ok := f.(string); ok {
-							collection = ns
-						}
+				m, err := asMap(g)
+				if err != nil {
+					return Fingerprint{}, err
+				}
+
+				if f, ok := m["key"]; ok {
+					retKeys = append(retKeys, keys(f, []string{})...)
+				}
+				if f, ok := m["cond"]; ok {
+					retKeys = append(retKeys, keys(f, []string{})...)
+				}
+				if f, ok := m["ns"]; ok {
+					if ns, ok := f.(string); ok {
+						collection = ns
 					}
 				}
 			}
@@ -210,14 +207,14 @@ func getKeys(query interface{}, keyFilters []string, level int) []string {
 	switch v := query.(type) {
 	case primitive.M:
 		q = append(q, v)
-	case []bson.M:
-		q = v
-	case primitive.A:
+	case primitive.D:
 		for _, intval := range v {
 			ks = append(ks, getKeys(intval, keyFilters, level+1)...)
 		}
 		return ks
-	case proto.BsonD:
+	case []bson.M:
+		q = v
+	case primitive.A:
 		for _, intval := range v {
 			ks = append(ks, getKeys(intval, keyFilters, level+1)...)
 		}
@@ -233,13 +230,13 @@ func getKeys(query interface{}, keyFilters []string, level int) []string {
 		return ks
 	}
 
-	if level <= MAX_DEPTH_LEVEL {
+	if level <= maxDepthLevel {
 		for i := range q {
 			for key, value := range q[i] {
 				if shouldSkipKey(key, keyFilters) {
 					continue
 				}
-				if matched, _ := regexp.MatchString("^\\$", key); !matched {
+				if !strings.HasPrefix(key, "$") {
 					ks = append(ks, key)
 				}
 
@@ -250,6 +247,7 @@ func getKeys(query interface{}, keyFilters []string, level int) []string {
 	return ks
 }
 
+// Check if a particular key should be excluded from the analysis based on the filters.
 func shouldSkipKey(key string, keyFilters []string) bool {
 	for _, filter := range keyFilters {
 		if matched, _ := regexp.MatchString(filter, key); matched {
@@ -271,3 +269,71 @@ func deduplicate(s []string) (r []string) {
 
 	return r
 }
+
+// GetQueryFieldD returns the correct field to build the fingerprint, based on the operation.
+func GetQueryFieldD(doc proto.SystemProfile) (primitive.M, error) {
+	// Proper way to detect if protocol used is "op_msg" or "op_command"
+	// would be to look at "doc.Protocol" field,
+	// however MongoDB 3.0 doesn't have that field
+	// so we need to detect protocol by looking at actual data.
+	query := doc.Query
+	if len(doc.Command) > 0 {
+		query = doc.Command
+		if doc.Op == "update" || doc.Op == "remove" {
+			return asMap(query.Map()["q"])
+		}
+	}
+
+	// "query" in MongoDB 3.0 can look like this:
+	// {
+	//  	"op" : "query",
+	//  	"ns" : "test.coll",
+	//  	"query" : {
+	//  		"a" : 1
+	//  	},
+	// 		...
+	// }
+	//
+	// but also it can have "query" subkey like this:
+	// {
+	//  	"op" : "query",
+	//  	"ns" : "test.coll",
+	//  	"query" : {
+	//  		"query" : {
+	//  			"$and" : [
+	//  			]
+	//  		},
+	//  		"orderby" : {
+	//  			"k" : -1
+	//  		}
+	//  	},
+	// 		...
+	// }
+	//
+	if squery, ok := query.Map()["query"]; ok {
+		return asMap(squery)
+	}
+
+	// "query" in MongoDB 3.2+ is better structured and always has a "filter" subkey:
+	if squery, ok := query.Map()["filter"]; ok {
+		return asMap(squery)
+	}
+
+	// {"ns":"test.system.js","op":"query","query":{"find":"system.js"}}
+	if len(query) == 1 && query[0].Key == "find" {
+		return primitive.M{}, nil
+	}
+
+	return query.Map(), nil
+}
+
+func asMap(field interface{}) (primitive.M, error) {
+	switch v := field.(type) {
+	case primitive.M:
+		return v, nil
+	case primitive.D:
+		return v.Map(), nil
+	default:
+		return nil, fmt.Errorf("don't know how to handle %T", v)
+	}
+}
