@@ -79,10 +79,10 @@ type SystemProfile struct {
 	NumYield           int       `bson:"numYield"`
 	Op                 string    `bson:"op"`
 	Protocol           string    `bson:"protocol"`
-	Query              BsonD     `bson:"query"`
-	UpdateObj          BsonD     `bson:"updateobj"`
-	Command            BsonD     `bson:"command"`
-	OriginatingCommand BsonD     `bson:"originatingCommand"`
+	Query              bson.D    `bson:"query"`
+	UpdateObj          bson.D    `bson:"updateobj"`
+	Command            bson.D    `bson:"command"`
+	OriginatingCommand bson.D    `bson:"originatingCommand"`
 	ResponseLength     int       `bson:"responseLength"`
 	Ts                 time.Time `bson:"ts"`
 	User               string    `bson:"user"`
@@ -104,10 +104,10 @@ func NewExampleQuery(doc SystemProfile) ExampleQuery {
 type ExampleQuery struct {
 	Ns                 string `bson:"ns" json:"ns"`
 	Op                 string `bson:"op" json:"op"`
-	Query              BsonD  `bson:"query,omitempty" json:"query,omitempty"`
-	Command            BsonD  `bson:"command,omitempty" json:"command,omitempty"`
-	OriginatingCommand BsonD  `bson:"originatingCommand,omitempty" json:"originatingCommand,omitempty"`
-	UpdateObj          BsonD  `bson:"updateobj,omitempty" json:"updateobj,omitempty"`
+	Query              bson.D `bson:"query,omitempty" json:"query,omitempty"`
+	Command            bson.D `bson:"command,omitempty" json:"command,omitempty"`
+	OriginatingCommand bson.D `bson:"originatingCommand,omitempty" json:"originatingCommand,omitempty"`
+	UpdateObj          bson.D `bson:"updateobj,omitempty" json:"updateobj,omitempty"`
 }
 
 func (self ExampleQuery) Db() string {
@@ -124,7 +124,7 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 
 	switch self.Op {
 	case "query":
-		if cmd.Len() == 0 {
+		if len(cmd) == 0 {
 			cmd = self.Query
 		}
 
@@ -137,15 +137,15 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 		//	 "$explain" : true
 		// },
 		if _, ok := cmd.Map()["$explain"]; ok {
-			cmd = BsonD{
+			cmd = bson.D{
 				{"explain", ""},
 			}
 			break
 		}
 
-		if cmd.Len() == 0 || cmd[0].Key != "find" {
+		if len(cmd) == 0 || cmd[0].Key != "find" {
 			var filter interface{}
-			if cmd.Len() > 0 && cmd[0].Key == "query" {
+			if len(cmd) > 0 && cmd[0].Key == "query" {
 				filter = cmd[0].Value
 			} else {
 				filter = cmd
@@ -157,7 +157,7 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 				coll = s[1]
 			}
 
-			cmd = BsonD{
+			cmd = bson.D{
 				{"find", coll},
 				{"filter", filter},
 			}
@@ -178,7 +178,6 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 					} else {
 						cmd = append(cmd[:i], cmd[i+1:]...)
 					}
-					break
 				}
 			}
 		}
@@ -188,13 +187,13 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 		if len(s) == 2 {
 			coll = s[1]
 		}
-		if cmd.Len() == 0 {
-			cmd = BsonD{
+		if len(cmd) == 0 {
+			cmd = bson.D{
 				{Key: "q", Value: self.Query},
 				{Key: "u", Value: self.UpdateObj},
 			}
 		}
-		cmd = BsonD{
+		cmd = bson.D{
 			{Key: "update", Value: coll},
 			{Key: "updates", Value: []interface{}{cmd}},
 		}
@@ -204,34 +203,34 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 		if len(s) == 2 {
 			coll = s[1]
 		}
-		if cmd.Len() == 0 {
-			cmd = BsonD{
+		if len(cmd) == 0 {
+			cmd = bson.D{
 				{Key: "q", Value: self.Query},
 				// we can't determine if limit was 1 or 0 so we assume 0
 				{Key: "limit", Value: 0},
 			}
 		}
-		cmd = BsonD{
+		cmd = bson.D{
 			{Key: "delete", Value: coll},
 			{Key: "deletes", Value: []interface{}{cmd}},
 		}
 	case "insert":
-		if cmd.Len() == 0 {
+		if len(cmd) == 0 {
 			cmd = self.Query
 		}
-		if cmd.Len() == 0 || cmd[0].Key != "insert" {
+		if len(cmd) == 0 || cmd[0].Key != "insert" {
 			coll := ""
 			s := strings.SplitN(self.Ns, ".", 2)
 			if len(s) == 2 {
 				coll = s[1]
 			}
 
-			cmd = BsonD{
+			cmd = bson.D{
 				{"insert", coll},
 			}
 		}
 	case "getmore":
-		if self.OriginatingCommand.Len() > 0 {
+		if len(self.OriginatingCommand) > 0 {
 			cmd = self.OriginatingCommand
 			for i := range cmd {
 				// drop $db param as it is not supported in MongoDB 3.0
@@ -245,16 +244,18 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 				}
 			}
 		} else {
-			cmd = BsonD{
+			cmd = bson.D{
 				{Key: "getmore", Value: ""},
 			}
 		}
 	case "command":
-		if cmd.Len() == 0 || cmd[0].Key != "group" {
+		cmd = sanitizeCommand(cmd)
+
+		if len(cmd) == 0 || cmd[0].Key != "group" {
 			break
 		}
 
-		if group, ok := cmd[0].Value.(BsonD); ok {
+		if group, ok := cmd[0].Value.(bson.D); ok {
 			for i := range group {
 				// for MongoDB <= 3.2
 				// "$reduce" : function () {}
@@ -284,3 +285,28 @@ func (self ExampleQuery) ExplainCmd() bson.D {
 		},
 	}
 }
+
+func sanitizeCommand(cmd bson.D) bson.D {
+	if len(cmd) < 1 {
+		return cmd
+	}
+
+	key := cmd[0].Key
+	if key != "count" && key != "distinct" {
+		return cmd
+	}
+
+	for i := range cmd {
+		// drop $db param as it is not supported in MongoDB 3.0
+		if cmd[i].Key == "$db" {
+			if len(cmd)-1 == i {
+				cmd = cmd[:i]
+			} else {
+				cmd = append(cmd[:i], cmd[i+1:]...)
+			}
+			break
+		}
+	}
+
+	return cmd
+}
