@@ -138,7 +138,7 @@ func TestStats(t *testing.T) {
 		t.Fatalf("cannot load samples: %s", err.Error())
 	}
 
-	fp := fingerprinter.NewFingerprinter(fingerprinter.DEFAULT_KEY_FILTERS)
+	fp := fingerprinter.NewFingerprinter(fingerprinter.DefaultKeyFilters())
 	s := New(fp)
 
 	err = s.Add(docs[1])
@@ -184,7 +184,7 @@ func TestStatsSingle(t *testing.T) {
 		t.Fatalf("cannot list samples: %s", err)
 	}
 
-	fp := fingerprinter.NewFingerprinter(fingerprinter.DEFAULT_KEY_FILTERS)
+	fp := fingerprinter.NewFingerprinter(fingerprinter.DefaultKeyFilters())
 
 	for _, file := range files {
 		f := file.Name()
@@ -217,7 +217,6 @@ func TestStatsSingle(t *testing.T) {
 			}
 		})
 	}
-
 }
 
 func TestStatsAll(t *testing.T) {
@@ -231,7 +230,7 @@ func TestStatsAll(t *testing.T) {
 		t.Fatalf("cannot list samples: %s", err)
 	}
 
-	fp := fingerprinter.NewFingerprinter(fingerprinter.DEFAULT_KEY_FILTERS)
+	fp := fingerprinter.NewFingerprinter(fingerprinter.DefaultKeyFilters())
 	s := New(fp)
 
 	for _, file := range files {
@@ -440,7 +439,7 @@ func TestAvailableMetrics(t *testing.T) {
 
 			fExpect := dirExpect + "cmd_metric.md"
 			if tutil.ShouldUpdateSamples() {
-				err = ioutil.WriteFile(fExpect, bufGot.Bytes(), 0777)
+				err = ioutil.WriteFile(fExpect, bufGot.Bytes(), os.ModePerm)
 				if err != nil {
 					fmt.Printf("cannot update samples: %s", err.Error())
 				}
